@@ -36,7 +36,7 @@ AboutWindow::AboutWindow(QWidget *parent) :
 #endif
 
 #ifdef Q_WS_MAEMO_5
-    setAttribute(Qt::WA_Maemo5NonComposited, true);
+    //setAttribute(Qt::WA_Maemo5NonComposited, true);
     setAttribute(Qt::WA_Maemo5AutoOrientation, true);
     setAttribute(Qt::WA_Maemo5StackedWindow);
     ui->scrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
