@@ -1,8 +1,6 @@
 #include "bookinfowindow.h"
 #include "ui_bookinfowindow.h"
-#ifdef Q_WS_MAEMO_5
-#include <QMaemo5Style>
-#endif
+#include "commonstatic.h"
 
 BookInfoWindow::BookInfoWindow(QWidget *parent, Book* book) :
     QDialog(parent),
@@ -15,10 +13,7 @@ BookInfoWindow::BookInfoWindow(QWidget *parent, Book* book) :
 #ifdef Q_WS_MAEMO_5
     setAttribute(Qt::WA_Maemo5AutoOrientation, true);
 
-    QColor secondaryColor = QMaemo5Style::standardColor("SecondaryTextColor");
-    QPalette secondaryPalette(QColor(255,255,255, 0));
-    secondaryPalette.setColor(QPalette::Foreground, secondaryColor);
-
+    QPalette secondaryPalette = CommonStatic::GetSecondaryPalette();
     ui->lblTitleD->setPalette(secondaryPalette);
     ui->lblAuthorsD->setPalette(secondaryPalette);
     ui->lblNumberD->setPalette(secondaryPalette);
