@@ -337,7 +337,8 @@ void BookWindow::ShowSection(int section)
             if (m_Section->Number == 0)
                 Save(GetBookSaveFilename(m_Book->Number), m_Player, m_Book->Number, m_Section->Number);
 
-            if (m_Section->AutoSave && m_Section->GetEnemiesCount() == 0 && !m_Player->IsDead()){
+            if (m_Section->AutoSave && m_Section->GetEnemiesCount() == 0 && !m_Player->IsDead() /*&&
+                m_Section->Choices.count() > 1*/){
                 Save(tempSaveFile, m_Player, m_Book->Number, m_Section->Number);
                 saved = true;
             }
@@ -972,7 +973,8 @@ bool BookWindow::Load(QString filename)
         if (m_Book->MinInterpreterVersion > interpreter){
             QMessageBox msgBox(this);
             msgBox.setIcon(QMessageBox::Warning);
-            msgBox.setText(QString("This book needs version %1 (you have %2)")
+            msgBox.setText(QString("'%1' book needs version %2 (you have %3)")
+                           .arg(m_Book->Title)
                            .arg(m_Book->MinInterpreterVersion.ToString())
                            .arg(interpreter.ToString()));
             msgBox.exec();
@@ -1152,6 +1154,8 @@ bool BookWindow::Load(QString filename)
             d = new Nexus(m_Player);
         else if (ele.at(0) == "Divination")
             d = new Divination(m_Player);
+        else if (ele.at(0) == "Pathsmanship")
+            d = new Pathsmanship(m_Player);
 
         if (d){
             d->FromString(discipline);
@@ -1325,6 +1329,20 @@ bool BookWindow::LoadNextBook()
         delete book;
         book = NULL;
         return false;
+    }else{
+        // Check book minimum interpreter version:
+        VersionClass interpreter;
+        interpreter.FromString(QCoreApplication::applicationVersion());
+        if (book->MinInterpreterVersion > interpreter){
+            QMessageBox msgBox(this);
+            msgBox.setIcon(QMessageBox::Warning);
+            msgBox.setText(QString("'%1' needs version %2 (you have %3)")
+                           .arg(m_Book->Title)
+                           .arg(m_Book->MinInterpreterVersion.ToString())
+                           .arg(interpreter.ToString()));
+            msgBox.exec();
+            return false;
+        }
     }
     m_Book = book;
     LoadBookFunctions();
