@@ -18,10 +18,11 @@ public:
         ChooseItem,
         ChooseItemExceptMeals,
         ChooseSpecialItem,
-        ChooseWeapon
+        ChooseWeapon,
+        ChooseWeaponSpecial
     };
 
-    explicit ChooseItemWindow(QWidget *parent = 0, Player* player=0, int mode=ChooseMeal);
+    explicit ChooseItemWindow(QWidget *parent = 0, Player* player=0, int mode=ChooseMeal, bool mandatory=true);
     ~ChooseItemWindow();
 
     Item* SelectedItem() { return m_Selected; }    
@@ -39,10 +40,11 @@ private:
     void ShowBackpackItems(bool excludeMeals=false);
     void ShowSpecialItems();
     void ShowMeals();
-    void ShowWeapons();
+    void ShowWeapons(bool special=false);
 
 private slots:
     void SelectedSlot();
+    void CancelSlot();
 };
 
 #endif // CHOOSEITEMWINDOW_H
