@@ -65,6 +65,8 @@ public slots:
     bool IsAborted() { return m_Abort; }
     /** Accepts the choice (used in the choice script to accept section navigation)*/
     void Accept() {m_Abort = false; }
+    /** Returns the target section of the choice*/
+    int GetTarget() { return Target; }
 };
 
 class Book;
@@ -121,6 +123,8 @@ public slots:
     bool RemoveItem(QString name);
     /** Adds one item to the section, returns the item added*/
     Item* AddItem(QString name, bool special);
+    /** Adds one item to the section*/
+    void AddItem(Item*);
     /** Copies all the items of the section to the given section*/
     void CopyItemsToSection(int section);
 };
