@@ -12,8 +12,18 @@ PropertiesItem::PropertiesItem(QObject *parent) :
 PropertiesItem::PropertiesItem(const PropertiesItem& item) :
     QObject(item.parent())
 {
-    foreach(QString key, item.Properties.keys())
-        Properties[key] = item.Properties[key];
+    QHash<QString, QString>::const_iterator i;
+    for (i = item.Properties.constBegin(); i != item.Properties.constEnd(); ++i){
+         Properties[i.key()] = i.value();
+    }
+}
+
+int PropertiesItem::GetIntProperty(QString name)
+{
+    QString p = GetProperty(name);
+    if (!p.isEmpty())
+        return p.toInt();
+    return 0;
 }
 
 QString PropertiesItem::GetProperty(QString name)
@@ -38,6 +48,7 @@ Item::Item(QObject *parent) :
     Description = "";
     SetQuantity(1);
     SetSize(1);
+    SetUsability(1);
 }
 
 Item::Item(const Item& item) :
@@ -106,6 +117,7 @@ void Item::Use(QScriptEngine* engine, QScriptValue* functions)
             msgBox.exec();
         }
     }
+    SetUsability(GetUsability() - 1);
 }
 
 bool Item::GetCanBeEquipped()
@@ -169,6 +181,13 @@ int Item::GetTotalSize()
     return GetSize();
 }
 
+bool Item::GetCanBeDropped()
+{
+    if (HasProperty("sys_CanBeDropped"))
+        return GetBoolProperty("sys_CanBeDropped");
+    return true;
+}
+
 
 Weapon::Weapon(QObject *parent) :
     Item(parent)
