@@ -197,15 +197,12 @@ int Player::GetCombatSkill(Enemy* enemy, QStringList* description)
 
             // Weaponskill
             Weaponskill* ws = qobject_cast<Weaponskill*>(d);
-            if (ws){
-                KaiDiscipline* td = GetDiscipline("Weaponmastery");
-                Weaponmastery* wm = td != NULL ? qobject_cast<Weaponmastery*>(td) : NULL;
+            if (ws && !HasWeaponmasteryBonus()){
                 bool done = false;
                 foreach(Item* i, Items){
                     if (i->GetIsWeapon()){
                         Weapon* w = (Weapon*)i;
-                        if (w->GetIsEquipped() && w->Classes().contains(ws->Weapon) &&
-                            (!wm || !wm->Weapons.contains(ws->Weapon))){
+                        if (w->GetIsEquipped() && w->Classes().contains(ws->Weapon)){
                             result += 2;
                             done = true;
                             if (description)
@@ -403,6 +400,28 @@ bool Player::HasWeaponskillBonus()
     return false;
 }
 
+bool Player::HasWeaponmasteryBonus()
+{
+    foreach (KaiDiscipline* d, KaiDisciplines){
+        if (QString::compare(d->Name, "Weaponmastery", Qt::CaseInsensitive) == 0){
+            Weaponmastery* wm = qobject_cast<Weaponmastery*>(d);
+            foreach(Item* i, Items){
+                if (i->GetIsWeapon()){
+                    Weapon* w = (Weapon*)i;
+                    if (w->GetIsEquipped()){
+                        foreach (int wc, w->Classes()){
+                            if (wm->Weapons.contains(wc))
+                                return true;
+                        }
+                    }
+                }
+            }
+            break;
+        }
+    }
+    return false;
+}
+
 bool Player::HasLoreCircle(QString name)
 {
     foreach (LoreCircle* lc, LoreCircles::Circles){
