@@ -108,6 +108,8 @@ public slots:
     bool HasWeaponmasteryIn(QString className);
     /** Return true if the player has a bonus due to the Weaponskill (check equipped weapon) */
     bool HasWeaponskillBonus();
+    /** Return true if the player has a bonus due to the Weaponmastery (check equipped weapon) */
+    bool HasWeaponmasteryBonus();
     /** Return the player's base endurance (the max value) includeing bonuses */
     int GetBaseEndurance();
     /** Return the player's base endurance (the max value) without bonuses */
