@@ -13,6 +13,7 @@ public:
 
     void GetRandomNumber(QWidget* labelParent=0, int* result=0);
     void SetBonus(int value) { m_Bonus = value; }
+    int GetLastRandomNumber() { return m_DiceValue; }
 
 private:
     bool m_Working;
@@ -26,6 +27,7 @@ private:
     int m_DiceValue;
 
 signals:
+    // Signal emitted with the random number + bonus value
     void Random(int);
 
 private slots:
